//	Copyright  2000.	GSI Technology
//						jeffd@gsitechnology.com
//  v 1.00  04/01/02    Jeff Daugherty  1) Created

`define		pipe
`define     SP250MHZ
//`define     SP220MHZ
//`define     SP225MHZ
//`define     SP166MHZ
//`define     SP150MHZ
//`define     SP133MHZ

`timescale 1ns / 100ps

module G864218B(A, DQa, DQb, nBa, nBb, CK, nADSC, nADSP, nBW,
		nGW, SCD, nE1, nG, nADV, ZZ, nFT, nLBO, ZQ, 
		TMS, TDI, TDO, TCK );
	parameter	ramtype		= 1,		// 1 burst
							// 2 NBT
							// 3 sigma
			ramversion	= 2,		// 0, 1, 2
			density 	= 64,		// 64M bit sram
			byteparl	= 4,		// 4 bytes in parallel
    			A_size 		= 22,		// +64M -4 bytes in parallel
			DQ_size 	= 9,
			bank_size 	= 1024*4096;	// *64M /4 bytes in parallel


	input	[A_size-1:0]	A; 		// address
	input			CK;		// clock
	input			nBa;		// bank A write enable
	input			nBb;		// bank B write enable
	input			nGW; 		// byte write enable
	input			nBW; 		// byte write enable
	input			nE1;		// chip enable 1
	input			nG;		// output enable
	input			nADV;		// Advance not / load
	input			nADSC;		// Advance not / load
	input			nADSP;		// Advance not / load
	inout	[DQ_size:1]	DQa;		// byte A data
	inout	[DQ_size:1]	DQb;		// byte B data
	input			ZZ;		// power down
	input			SCD;		// power down
	input			nFT;		// Pipeline / Flow through
	input			nLBO;		// Linear Burst Order not
	input			ZQ;

	input			TMS;		// Scan Test Mode Select
	input			TDI;		// Scan Test Data In
	output			TDO;		// Scan Test Data Out
	input			TCK;		// Scan Test Clock

//  State machine signals

	wire			nPE = 0;
	wire			E2  = 1;
	wire			nE3 = 0;
	wire			nBc=1,
				nBd=1,
				nBe=1,
				nBf=1,
				nBg=1,
				nBh=1;

	wire			gonew,
				gobur;
	assign			gonew = ~nE1 & E2 & ~nE3 & ~nADV;
	assign			gobur = nADV;

	wire   [DQ_size:1]	DQc,
				DQd,
				DQe,
				DQf,
				DQg,
				DQh;
//  ******** Define Sram Operation Mode    ********************** 
	wire			NBT;		// NBT=1 activates NBT operation 
	wire			DDR;	 	// DDR=1 activates Double Data Rate
	assign			NBT = 0;
	assign			DDR = 0;
//  ******** Define Sram Option Setting   ********************** 
//JTAG SECTION
   wire		toe,clockbsr,extest,samplez,shiftdr,updatedr,tdiin;
   wire [199:0] bsr;  // 200 scan cells total

// %%% Set ID
//   parameter 	JTAGID = 32'h000081b3; // x36
   parameter JTAGID = 32'h0000a1b3; // x18
/*
tapcontrol #(JTAGID) itap(
                .TCK(TCK), .TDI(TDI), .TMS(TMS), .TDO(TDO), 
                .bsrin(bsr[0]), .tdiin(tdiin),
                .clockBSR(clockbsr), .extest(extest), 
                .samplez(samplez), .shiftDR(shiftdr), .updateDR(updatedr) 
                );*/
   wire [1:0] jctl0;
   wire [4:0] jctl1;
   wire [2:0] jctl2;
   assign  jctl0={clockbsr,shiftdr};
   assign  jctl1={extest,toe,updatedr,clockbsr,shiftdr};
   assign  jctl2={updatedr,clockbsr,shiftdr};

//---------------------------------------------------------------
// 	Scan Registers 
//---------------------------------------------------------------

   wire pdis; 
   assign 	pdis="X";
   	
// END JTAG SECTION

`ifdef SP250MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 2.5;

        specify
            specparam
    		tKC		= 4,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    		tS		= 1.2,	// setup time
    		tH		= 0.2;	// hold time
    `else
    		// flowthrough
    	parameter tKQ = 6.5;
    
        specify
            specparam
    		tKC		= 6.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
    `endif
`endif  // ------------------------------------------------------------------

`ifdef SP225MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
    	parameter tKQ = 2.7;
    
        specify
            specparam
    		tKC		= 4.4,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    		tS		= 1.3,	// setup time
    		tH		= 0.3;	// hold time
    `else
    		// flowthrough
	        parameter tKQ = 7.0;

        specify
            specparam
    		tKC		= 7.0	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
    `endif
`endif  // ------------------------------------------------------------------

`ifdef SP200MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 3.0;

        specify
            specparam
    		tKC		= 5,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    		tS		= 1.4,	// setup time
    		tH		= 0.4;	// hold time
    `else
    		// flowthrough
    	parameter tKQ = 7.5;
    
        specify
            specparam
    		tKC		= 7.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
    `endif
`endif  // ------------------------------------------------------------------

`ifdef SP166MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 3.4;

        specify
            specparam
    		tKC		= 6,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    `else
    		// flowthrough
    	parameter tKQ = 8.0;
    
        specify
            specparam
    		tKC		= 8.0,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    `endif
    		// common
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
`endif  // ------------------------------------------------------------------

`ifdef SP150MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 3.8;

        specify
            specparam
    		tKC		= 6.7,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    `else
    		// flowthrough
    	parameter tKQ = 8.5;
    
        specify
            specparam
    		tKC		= 8.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    `endif
    		// common
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
`endif  // ------------------------------------------------------------------

`ifdef SP133MHZ //-----------------------------------------------------------
    `ifdef pipe
    		// pipeline
	    parameter tKQ = 4.0;

        specify
            specparam
    		tKC		= 7.5,	// clock cycle time
    		tKQX		= 1.5,	// clock to output invalid
    		tLZ		= 1.5,	// clock to output in LOW-Z
    `else
    		// flowthrough
    	parameter tKQ = 8.5;
    
        specify
            specparam
    		tKC		= 8.5,	// clock cycle time
    		tKQX		= 3,	// clock to output invalid
    		tLZ		= 3,	// clock to output in LOW-Z
    `endif
    		// common
    		tS		= 1.5,	// setup time
    		tH		= 0.5;	// hold time
`endif  // ------------------------------------------------------------------

        $setuphold  ( posedge CK, nGW,  tS, tH );  
        $setuphold  ( posedge CK, nBa,  tS, tH );  
        $setuphold  ( posedge CK, nBb,  tS, tH );  
        $setuphold  ( posedge CK, nE1,  tS, tH );  
        $setuphold  ( posedge CK, E2,   tS, tH );  
        $setuphold  ( posedge CK, nE3,  tS, tH );  
        $setuphold  ( posedge CK, nG,   tS, tH );  
        $setuphold  ( posedge CK, nADV, tS, tH );  
        $setuphold  ( posedge CK, nFT,  tS, tH );  
        $setuphold  ( posedge CK, nLBO, tS, tH );  
        $setuphold  ( posedge CK, DQa, tS, tH );    // Dq  
        $setuphold  ( posedge CK, DQb, tS, tH );    // Dq  
	endspecify
/*
// JTAG BSR
inbsr ibsr0   	(.pin(pdis), 	.nextc(bsr[0]), .lastc(bsr[1]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr1   	(.pin(A[18]), 	.nextc(bsr[1]), .lastc(bsr[2]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr2   	(.pin(A[17]), 	.nextc(bsr[2]), .lastc(bsr[3]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr3   	(.pin(A[12]), 	.nextc(bsr[3]), .lastc(bsr[4]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr4   	(.pin(A[13]), 	.nextc(bsr[4]), .lastc(bsr[5]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr5   	(.pin(A[4]), 	.nextc(bsr[5]), .lastc(bsr[6]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr6   	(.pin(A[5]), 	.nextc(bsr[6]), .lastc(bsr[7]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr7   	(.pin(A[15]), 	.nextc(bsr[7]), .lastc(bsr[8]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr8   	(.pin(A[14]), 	.nextc(bsr[8]), .lastc(bsr[9]),	 .pineb('b0), .jctl(jctl0) );
inbsr ibsr9   	(.pin(A[16]), 	.nextc(bsr[9]), .lastc(bsr[10]), .pineb('b0), .jctl(jctl0) );

inbsr ibsr10   	(.pin(pdis), 	.nextc(bsr[10]), .lastc(bsr[11]),.pineb('b0), .jctl(jctl0) );
inbsr ibsr11   	(.pin(pdis), 	.nextc(bsr[11]), .lastc(bsr[12]),.pineb('b0), .jctl(jctl0) );

iobsr ibsr12   	(.pin(pdis), 	.nextc(bsr[12]),.lastc(bsr[14]),.n0(bsr[13]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr14   	(.pin(pdis), 	.nextc(bsr[14]),.lastc(bsr[16]),.n0(bsr[15]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr16   	(.pin(pdis), 	.nextc(bsr[16]),.lastc(bsr[18]),.n0(bsr[17]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr18   	(.pin(pdis), 	.nextc(bsr[18]),.lastc(bsr[20]),.n0(bsr[19]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr20   	(.pin(pdis), 	.nextc(bsr[20]),.lastc(bsr[22]),.n0(bsr[21]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr22   	(.pin(pdis), 	.nextc(bsr[22]),.lastc(bsr[24]),.n0(bsr[23]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr24   	(.pin(pdis), 	.nextc(bsr[24]),.lastc(bsr[26]),.n0(bsr[25]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr26   	(.pin(pdis), 	.nextc(bsr[26]),.lastc(bsr[28]),.n0(bsr[27]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr28   	(.pin(pdis), 	.nextc(bsr[28]),.lastc(bsr[30]),.n0(bsr[29]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr30   	(.pin(pdis), 	.nextc(bsr[30]),.lastc(bsr[32]),.n0(bsr[31]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr32  	(.pin(pdis), 	.nextc(bsr[32]), .lastc(bsr[33]),.pineb('b0), .jctl(jctl0) );

iobsr ibsr33   	(.pin(DQa[1]), 	.nextc(bsr[33]),.lastc(bsr[35]),.n0(bsr[34]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr35   	(.pin(pdis), 	.nextc(bsr[35]),.lastc(bsr[37]),.n0(bsr[36]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr37   	(.pin(DQa[2]), 	.nextc(bsr[37]),.lastc(bsr[39]),.n0(bsr[38]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr39   	(.pin(pdis), 	.nextc(bsr[39]),.lastc(bsr[41]),.n0(bsr[40]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr41   	(.pin(DQa[3]), 	.nextc(bsr[41]),.lastc(bsr[43]),.n0(bsr[42]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr43   	(.pin(pdis), 	.nextc(bsr[43]),.lastc(bsr[45]),.n0(bsr[44]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr45   	(.pin(DQa[4]), 	.nextc(bsr[45]),.lastc(bsr[47]),.n0(bsr[46]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr47   	(.pin(pdis), 	.nextc(bsr[47]),.lastc(bsr[49]),.n0(bsr[48]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr49  	(.pin(ZZ), 	.nextc(bsr[49]),.lastc(bsr[50]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr50  	(.pin(pdis), 	.nextc(bsr[50]),.lastc(bsr[51]), .pineb('b0), .jctl(jctl0) );

iobsr ibsr51   	(.pin(DQa[5]), 	.nextc(bsr[51]), .lastc(bsr[53]),.n0(bsr[42]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr53   	(.pin(pdis), 	.nextc(bsr[53]), .lastc(bsr[55]),.n0(bsr[54]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr55   	(.pin(DQa[6]), 	.nextc(bsr[55]), .lastc(bsr[57]),.n0(bsr[56]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr57   	(.pin(pdis), 	.nextc(bsr[57]), .lastc(bsr[59]),.n0(bsr[58]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr59   	(.pin(DQa[7]), 	.nextc(bsr[59]), .lastc(bsr[61]),.n0(bsr[60]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr61   	(.pin(pdis), 	.nextc(bsr[61]), .lastc(bsr[63]),.n0(bsr[62]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr63   	(.pin(DQa[8]), 	.nextc(bsr[63]), .lastc(bsr[65]),.n0(bsr[64]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr65   	(.pin(pdis), 	.nextc(bsr[65]), .lastc(bsr[67]),.n0(bsr[66]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr67  	(.pin(pdis), 	.nextc(bsr[67]), .lastc(bsr[68]),.pineb('b0), .jctl(jctl0) );

iobsr ibsr68   	(.pin(DQa[9]), 	.nextc(bsr[68]), .lastc(bsr[70]),.n0(bsr[69]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr70   	(.pin(pdis), 	.nextc(bsr[70]), .lastc(bsr[72]),.n0(bsr[71]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr72  	(.pin(pdis), 	.nextc(bsr[72]), .lastc(bsr[74]),.n0(bsr[73]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr74   	(.pin(pdis), 	.nextc(bsr[74]), .lastc(bsr[76]),.n0(bsr[75]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr76   	(.pin(pdis), 	.nextc(bsr[76]), .lastc(bsr[78]),.n0(bsr[77]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr78   	(.pin(pdis), 	.nextc(bsr[78]), .lastc(bsr[80]),.n0(bsr[79]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr80   	(.pin(pdis), 	.nextc(bsr[80]), .lastc(bsr[82]),.n0(bsr[81]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr82   	(.pin(pdis), 	.nextc(bsr[82]), .lastc(bsr[84]),.n0(bsr[83]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr84   	(.pin(pdis), 	.nextc(bsr[84]), .lastc(bsr[86]),.n0(bsr[85]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr86   	(.pin(pdis), 	.nextc(bsr[86]), .lastc(bsr[88]),.n0(bsr[87]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr88  	(.pin(A[20]), 	.nextc(bsr[88]),  .lastc(bsr[89]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr89  	(.pin(A[9]), 	.nextc(bsr[89]),  .lastc(bsr[80]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr90  	(.pin(A[8]), 	.nextc(bsr[90]),  .lastc(bsr[81]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr91  	(.pin(nADV), 	.nextc(bsr[91]),  .lastc(bsr[82]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr92  	(.pin(nADSP),	.nextc(bsr[92]),  .lastc(bsr[93]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr93  	(.pin(nADSC),	.nextc(bsr[93]),  .lastc(bsr[94]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr94  	(.pin(nG),	.nextc(bsr[94]),  .lastc(bsr[95]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr95  	(.pin(nBW),	.nextc(bsr[95]),  .lastc(bsr[96]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr96  	(.pin(nGW),	.nextc(bsr[96]),  .lastc(bsr[97]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr97  	(.pin(pdis), 	.nextc(bsr[97]),  .lastc(bsr[98]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr98  	(.pin(pdis), 	.nextc(bsr[98]),  .lastc(bsr[99]),  .pineb('b0), .jctl(jctl0) );
inbsr ibsr99  	(.pin(pdis), 	.nextc(bsr[99]),  .lastc(bsr[100]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr100 	(.pin(pdis), 	.nextc(bsr[100]), .lastc(bsr[101]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr101	(.pin(CK),	.nextc(bsr[101]), .lastc(bsr[102]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr102	(.pin(ZQ),	.nextc(bsr[102]), .lastc(bsr[103]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr103	(.pin(pdis),	.nextc(bsr[103]), .lastc(bsr[104]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr104 	(.pin(nE3),	.nextc(bsr[104]), .lastc(bsr[105]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr105 	(.pin(nBa),	.nextc(bsr[105]), .lastc(bsr[106]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr106 	(.pin(pdis),	.nextc(bsr[106]), .lastc(bsr[107]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr107 	(.pin(nBb),	.nextc(bsr[107]), .lastc(bsr[108]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr108 	(.pin(pdis),	.nextc(bsr[108]), .lastc(bsr[109]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr109 	(.pin(E2),	.nextc(bsr[109]), .lastc(bsr[110]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr110 	(.pin(nE1),	.nextc(bsr[110]), .lastc(bsr[111]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr111 	(.pin(A[7]),	.nextc(bsr[111]), .lastc(bsr[112]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr112 	(.pin(A[6]),	.nextc(bsr[112]), .lastc(bsr[113]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr113 	(.pin(pdis), 	.nextc(bsr[113]), .lastc(bsr[114]), .pineb('b0), .jctl(jctl0) );

iobsr ibsr114  	(.pin(pdis), 	.nextc(bsr[114]), .lastc(bsr[116]), .n0(bsr[115]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr116  	(.pin(pdis), 	.nextc(bsr[116]), .lastc(bsr[118]), .n0(bsr[117]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr118  	(.pin(pdis), 	.nextc(bsr[118]), .lastc(bsr[120]), .n0(bsr[119]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr120  	(.pin(pdis), 	.nextc(bsr[120]), .lastc(bsr[122]), .n0(bsr[121]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr122  	(.pin(pdis), 	.nextc(bsr[122]), .lastc(bsr[124]), .n0(bsr[123]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr124  	(.pin(pdis), 	.nextc(bsr[124]), .lastc(bsr[126]), .n0(bsr[125]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr126  	(.pin(pdis), 	.nextc(bsr[126]), .lastc(bsr[128]), .n0(bsr[127]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr128  	(.pin(pdis), 	.nextc(bsr[128]), .lastc(bsr[130]), .n0(bsr[129]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr130  	(.pin(pdis), 	.nextc(bsr[130]), .lastc(bsr[132]), .n0(bsr[131]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr132  	(.pin(pdis), 	.nextc(bsr[132]), .lastc(bsr[134]), .n0(bsr[133]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr134 	(.pin(pdis), 	.nextc(bsr[134]), .lastc(bsr[135]), .pineb('b0), .jctl(jctl0) );

iobsr ibsr135  	(.pin(DQb[1]), 	.nextc(bsr[135]), .lastc(bsr[137]), .n0(bsr[136]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr137  	(.pin(pdis), 	.nextc(bsr[137]), .lastc(bsr[139]), .n0(bsr[138]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr139  	(.pin(DQb[2]), 	.nextc(bsr[139]), .lastc(bsr[141]), .n0(bsr[140]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr141  	(.pin(pdis), 	.nextc(bsr[141]), .lastc(bsr[143]), .n0(bsr[142]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr143  	(.pin(DQb[3]), 	.nextc(bsr[143]), .lastc(bsr[145]), .n0(bsr[144]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr145  	(.pin(pdis), 	.nextc(bsr[145]), .lastc(bsr[147]), .n0(bsr[146]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr147  	(.pin(DQb[4]), 	.nextc(bsr[147]), .lastc(bsr[149]), .n0(bsr[148]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr149  	(.pin(pdis), 	.nextc(bsr[149]), .lastc(bsr[151]), .n0(bsr[150]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr151 	(.pin(nFT),	.nextc(bsr[151]), .lastc(bsr[152]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr152 	(.pin(SCD),	.nextc(bsr[152]), .lastc(bsr[153]), .pineb('b0), .jctl(jctl0) );

iobsr ibsr153  	(.pin(DQb[5]), 	.nextc(bsr[153]), .lastc(bsr[155]),.n0(bsr[154]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr155  	(.pin(pdis), 	.nextc(bsr[155]), .lastc(bsr[157]),.n0(bsr[156]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr157  	(.pin(DQb[6]), 	.nextc(bsr[157]), .lastc(bsr[159]),.n0(bsr[158]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr159  	(.pin(pdis), 	.nextc(bsr[159]), .lastc(bsr[161]),.n0(bsr[160]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr161  	(.pin(DQb[7]), 	.nextc(bsr[161]), .lastc(bsr[163]),.n0(bsr[162]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr163  	(.pin(pdis), 	.nextc(bsr[163]), .lastc(bsr[165]),.n0(bsr[164]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr165  	(.pin(DQb[8]), 	.nextc(bsr[165]), .lastc(bsr[167]),.n0(bsr[166]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr167  	(.pin(pdis), 	.nextc(bsr[167]), .lastc(bsr[169]),.n0(bsr[168]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr169 	(.pin(pdis), 	.nextc(bsr[169]), .lastc(bsr[170]), .pineb('b0), .jctl(jctl0) );

iobsr ibsr170  	(.pin(DQb[9]), 	.nextc(bsr[170]), .lastc(bsr[172]),.n0(bsr[171]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr172  	(.pin(pdis), 	.nextc(bsr[172]), .lastc(bsr[174]),.n0(bsr[173]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr174  	(.pin(pdis), 	.nextc(bsr[174]), .lastc(bsr[176]),.n0(bsr[175]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr176  	(.pin(pdis), 	.nextc(bsr[176]), .lastc(bsr[178]),.n0(bsr[177]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr178  	(.pin(pdis), 	.nextc(bsr[178]), .lastc(bsr[180]),.n0(bsr[179]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr180  	(.pin(pdis), 	.nextc(bsr[180]), .lastc(bsr[182]),.n0(bsr[181]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr182  	(.pin(pdis), 	.nextc(bsr[182]), .lastc(bsr[184]),.n0(bsr[183]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr184  	(.pin(pdis), 	.nextc(bsr[184]), .lastc(bsr[186]),.n0(bsr[185]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr186  	(.pin(pdis), 	.nextc(bsr[186]), .lastc(bsr[188]),.n0(bsr[187]), .pineb('b0), .jctl(jctl1) );
iobsr ibsr188  	(.pin(pdis), 	.nextc(bsr[188]), .lastc(bsr[190]),.n0(bsr[189]), .pineb('b0), .jctl(jctl1) );

inbsr ibsr190 	(.pin(nLBO),	.nextc(bsr[190]), .lastc(bsr[191]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr191 	(.pin(A[3]),	.nextc(bsr[191]), .lastc(bsr[192]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr192 	(.pin(A[2]),	.nextc(bsr[192]), .lastc(bsr[193]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr193 	(.pin(A[11]),	.nextc(bsr[193]), .lastc(bsr[194]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr194 	(.pin(A[10]),	.nextc(bsr[194]), .lastc(bsr[195]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr195 	(.pin(A[0]),	.nextc(bsr[195]), .lastc(bsr[196]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr196 	(.pin(A[1]),	.nextc(bsr[196]), .lastc(bsr[197]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr197 	(.pin(pdis), 	.nextc(bsr[197]), .lastc(bsr[198]), .pineb('b0), .jctl(jctl0) );
inbsr ibsr198 	(.pin(A[19]),	.nextc(bsr[198]), .lastc(bsr[199]), .pineb('b0), .jctl(jctl0) );
oebsr ibsr199 	(.pin(nG),	.nextc(bsr[199]), .lastc(tdiin   ), .toe(toe),   .jctl(jctl2) );
// END JTAG BSR
*/
`include	"core.v"

endmodule
